% Calibrate the model via SMM
clear all
clc

%% Housekeeping
restoredefaultpath
addpath(genpath('C:\Program Files\Exe\NotYADA\Dynare\4.1.0\matlab'))

s = RandStream.create('mt19937ar','seed',5489);
RandStream.setGlobalStream(s);

%% Set moments to be matched

MOM_data = [-.2977; ... % wedge cyclicality, correlation(growth, wedge)
            0.6439 ; ... % wedge persistence
            0.1852; ... % wedge variance
            1];         % impose both long rates equally volatile
        
save MD MOM_data
%% Set bounds and guess
LB = [0.001; 0.001; 0.001];
UB = [0.999; 0.999; 50];

% guess=[
%     0.1, 0.5, 0.001;...
%     0.1, 0.5, 0.01;...
%     0.1, 0.9, 0.001;...
%     0.1, 0.9, 0.01;...
%     0.5, 0.9, 0.001;...
%     0.5, 0.9, 0.01;...
%     0.5, 0.5, 0.001;...
%     0.5, 0.5, 0.01;
% 	0.9, 0.9, 0.001;...
%     0.9, 0.9, 0.01;...
%     0.9, 0.5, 0.001;...
%     0.9, 0.5, 0.01]';


guess=[
    0.27786, 0.77127, 0.00864]';


%% More housekeeping
options = optimset('Display','iter','LargeScale','on','MaxIter',5000,'MaxFunEvals',5000,'TolFun',.00001); %1e-10);
iter = size(guess,2);

results.xpar        = NaN * zeros(size(MOM_data,1),iter);
results.fval        = 1e10 * zeros(1,iter);
results.param_cal   = NaN * zeros(size(LB,1),iter);
results.guess       = guess;
jj = 1;


%% Starting loop
while jj < iter + 1
    [param_cal,fval] = fmincon(@OBJ_func_loop, guess(:,jj), [], [], [], [], LB, UB, [], options);

    xpar = MOM_func_alt(param_cal);
    
    results.param_cal(:,jj) = param_cal;
    results.fval(1,jj)      = fval;
    results.xpar(:,jj)      = xpar;
    
    jj = jj + 1;
end


results.param_cal
results.fval
results.xpar

