% clear all
% close all
% clc

path(path,'C:/Program Files/Exe/NotYADA/Dynare/4.1.0/matlab')

%% Parameter setting Model calibration 1

% Parameters, household and producers
para.betaP     = (1.026417)^(-1/4);     % discount factor unrestricted households
para.sigmaP     = 1;        % inverse of IES
para.vphiP      = 3;        % Frisch elasticity
para.alphaP     = 0.75;     % Prob. of no price change
para.thetaP     = 11;       % Elas. of sub. intermediate goods
para.tauP       = 0.00001;   % Elasticity of fin. cost. wrt. restricted bond holdings


% implied parameters
para.kappaP = (1 - para.alphaP) * (1 - para.alphaP * para.betaP)...
    / para.alphaP;                                                          % slope of NKPC

% Monetary policy parameters
para.rhoiP      = 0.85;     % Inertia MP rule, Ramses = 0.8235
para.psipiP     = 2;        % Reaction to inflation, Ramses = 1.7277
para.psiyP      = 0.5/4;    % Reaction to output, Ramses (hours) = 0.0270

% Market clearing parameters
% para.omegaP     = 0.8218;   % Fraction of unrestricted agents, SWE = 0.8218, US  = 0.3617       

% Stochastic process parameters
para.rho_ucP    = 0.80;      % autocorr. cons. pref, Ramses = 0.7978
para.rho_ulP    = 0;      % autocorr. labor supply
para.rho_uzP    = 0.95;   % autocorr. productivity, Ramses = 0.9545
para.rho_ugP    = 0;      % autocorr. gov spend
para.rho_uiP    = 0;      % autocorr. monetary, Ramses = 0
% para.rho_uphiP  = 0.1753; % autocorr. transaction costs, SWE = 0.1753, US  = 0.4935 

para.sig_ucP    = 0;      % std. dev. cons. pref, Ramses = 0.2110/10
para.sig_ulP    = 0;      % std. dev. labor supply
para.sig_uzP    = 0;      % std. dev. productivity, Ramses = 0.4367/100
para.sig_ugP    = 0;      % std. dev. gov spend
para.sig_uiP    = 0;      % std. dev. monetary, Ramses = 0.0793/100
% para.sig_uphiP  = 0.6630; % std. dev. transaction costs, SWE = 0.6630, US = 1.8393

% Steady state values
% free steady state values
para.gyS    = 0.3;          % Government spending as fraction of output

% Implied steady state values
para.wS     = (para.thetaP - 1) / para.thetaP;                              % wage rate
para.cS     = ((1-para.gyS) ^ para.vphiP * (para.thetaP - 1)...
    / para.thetaP) ^ (1/(para.vphiP + para.sigmaP));                        % aggregate consumption
para.yS     = para.cS ^ (-para.sigmaP / para.vphiP) * ((para.thetaP - 1)...
    / para.thetaP) ^ (1 / para.vphiP);                                      % aggregate output
para.gS     = para.yS * para.gyS;                                           % aggregate public spending
para.tS     = -para.gS;                                                     % transfers
para.dS    = 1 / para.thetaP * para.yS;                                     % dividends


save para para
dynare MIR_version2 noclearall


