function int = SetupForwardData

%% Reading data, defining policy rounds and last obs date
[data,txt,raw]=xlsread('RepoLongRate.xlsx','Forward','a1:aw155');
% [data_outc,txt_outc,raw_outc]=xlsread('DataOutcomes_20130930.xlsx','Blad1','a1:e156');

policy_rounds = {  
    'PPR 2007:1'    '2006-11-15'
    'PPR 2007:2'    '2007-02-15' % in the excel file from www.riksbank.se q2 is listed as observed even though the update was published 2007-06-20. Last obs could be changed to 2007-02-15
    'PPR 2007:3'    '2007-08-15'
    'PPU 2007:1'    '2007-08-15' % in the excel file from www.riksbank.se q4 is listed as observed even though the update was published 2007-12-19. Last obs could be changed to 2007-08-15 
    'PPR 2008:1'    '2007-11-15'
    'PPU 2008:1'    '2008-02-15'
    'PPR 2008:2'    '2008-05-15'
    'PPU 2008:2'    '2008-05-15'
    'PPR 2008:3'    '2008-08-15'
    'PPU 2008:3'    '2008-08-15'  
    'PPR 2009:1'    '2008-11-15' 
    'PPU 2009:1'    '2009-02-15'
    'PPR 2009:2'    '2009-05-15'
    'PPU 2009:2'    '2009-05-15'
    'PPR 2009:3'    '2009-08-15'
    'PPU 2009:3'    '2009-08-15'
    'PPR 2010:1'    '2009-11-15'
    'PPU 2010:1'    '2010-02-15'
    'PPR 2010:2'    '2010-05-15'
    'PPU 2010:2'    '2010-05-15'
    'PPR 2010:3'    '2010-08-15'
    'PPU 2010:3'    '2010-08-15'
    'PPR 2011:1'    '2010-11-15'
    'PPU 2011:1'    '2011-02-15'
    'PPR 2011:2'    '2011-05-15'
    'PPU 2011:2'    '2011-05-15'
    'PPR 2011:3'    '2011-08-15'
    'PPU 2011:3'    '2011-08-15'
    'PPR 2012:1'    '2011-11-15'
    'PPU 2012:1'    '2012-02-15'
    'PPR 2012:2'    '2012-05-15'
    'PPU 2012:2'    '2012-05-15'
    'PPR 2012:3'    '2012-08-15'
    'PPU 2012:3'    '2012-08-15'
    'PPR 2013:1'    '2012-11-15'
    'PPU 2013:1'    '2013-02-15'
    'PPR 2013:2'    '2013-05-15'
    'PPU 2013:2'    '2013-05-15'
    'PPR 2013:3'    '2013-08-15' % new rounds in version 2
    'PPU 2013:3'    '2013-08-15'
    'PPR 2014:1'    '2013-11-15'
    'PPU 2014:1'    '2014-02-15'
    'PPR 2014:2'    '2014-05-15'
    'PPU 2014:2'    '2014-05-15'
    'PPR 2014:3'    '2014-08-15'
    'PPU 2014:3'    '2014-08-15'
    'PPR 2015:1'    '2014-11-15'
    'PPR 2015:2'    '2015-02-15'

    };


%% Data handling
% picking out int outcome data and dates
dates       = txt(2:end,1);

%% Setting date format
for i = 1:size(dates,1)
    int_date = char(dates(i));
    if strcmp(int_date(6:7),'03') == 1
        month_date = '02';
    elseif strcmp(int_date(6:7),'06') == 1
        month_date = '05';
    elseif strcmp(int_date(6:7),'09') == 1
        month_date = '08';
    elseif strcmp(int_date(6:7),'12') == 1
        month_date = '11';        
    end
    date_str = [int_date(1:4), '-', month_date, '-15'];
    dates{i} = date_str;
end
% keyboard
%% Defining output structures
int.dates           = dates;
int.data	        = NaN * zeros(size(data,1),size(policy_rounds,1));
int.round           = cell(3,size(policy_rounds,1));
int.longrates       = NaN * zeros(4,size(policy_rounds,1));

%% Computations 
jj = 1;
kk = 1;
for i = 1:size(policy_rounds,1)
    policy_round_index = strcmp(policy_rounds(i,1), txt(1,2:end));
    end_outc_index = find(strcmp(policy_rounds(i,2), dates));
    int.data(end_outc_index+1:end,jj) = data(end_outc_index+1:end, policy_round_index);

    for k = [1,4,8,12]
        int.longrates(kk,jj) = mean(data(end_outc_index+1:end_outc_index+k, policy_round_index));
        kk = kk + 1;
    end

    int.round{1,jj} = policy_rounds(i,1);
    int.round(2,jj) = dates(find(~isnan(int.data(:,jj)),1,'first'));
    int.round(3,jj) = dates(find(~isnan(int.data(:,jj)),1,'last'));
    jj = jj + 1;
    kk = 1;
end