clear all
% close all
clc

path(path,'C:/Program Files/Exe/NotYADA/Dynare/4.1.0/matlab')
% addpath('S:\APP\APP_Modellenheten\Projekt\2013\MultipleInterestRateProject\Jens\Dynare\ComparingModels')

%% User control
PlotStruct.NegShock     = 0;    % Indicates whether a positive or negative innovation to the shock is ploted
PlotStruct.periods      = 20;   % Number of periods of IRF to be plotted

PlotStruct.Normalize    = 1;        % Indicates whether normalized IRF's (so initial impulse is the same across the calibrations) are plotted
PlotStruct.normvar      = 'tpaU';   % Indicates which variable should be normalized
PlotStruct.normsize     = -0.37;       % Determines the response of normvar

PlotStruct.varnames     = {     % Variables to be plotted    
    'piaU'       'Inflation'
    'yaU'        'Output gap'
    'iaU'        'Policy rate'
    'cuaU'       'Consumption: unrestricted'
    'iLCBaU'     'Long rate: CB (unrestricted)'
    'phiU'       'Transaction costs'
    'craU'       'Consumption: restricted'
    'iLMaU'      'Long rate: M (restricted)'
    'tpaU'       'Wedge (CB-M)'
};
% keyboard
PlotStruct.shockname = 'uphiU_eps';     % Shock for which IRF is to be plotted, NB: only a single shock can be plotted at the time
% ucU_eps
% ulU_eps
% uzU_eps
% ugU_eps
% uiU_eps
% utU_eps 
% ubU_eps 
% uphiU_eps

save PlotStruct PlotStruct
    
%% Parameter setting first calibration
% Parameters, household and producers
para.betaP     = (1.026417)^(-1/4);     % discount factor
para.sigmaP     = 1;        % inverse of IES
para.vphiP      = 3;        % Frisch elasticity
para.alphaP     = 0.75;     % Prob. of no price change
para.thetaP     = 11;       % Elas. of sub. intermediate goods
para.tauP       = 0.00001;   % Elasticity of fin. cost. wrt. restricted bond holdings


% implied parameters
para.kappaP = (1 - para.alphaP) * (1 - para.alphaP * para.betaP)...
    / para.alphaP;                                                          % slope of NKPC

% Monetary policy parameters
para.rhoiP      = 0.85;     % Inertia MP rule
para.psipiP     = 2;        % Reaction to inflation
para.psiyP      = 0.5/4;    % Reaction to output

% Market clearing parameters
para.omegaP     = 0.5;      % Fraction of unrestricted agents

% Stochastic process parameters
para.rho_ucP    = 0;      % autocorr. cons. pref
para.rho_ulP    = 0;      % autocorr. labor supply
para.rho_uzP    = 0;      % autocorr. productivity
para.rho_ugP    = 0;      % autocorr. gov spend
para.rho_uiP    = 0;      % autocorr. monetary
para.rho_uphiP  = 0.5;      % autocorr. transaction costs

para.sig_ucP    = 0;      % std. dev. cons. pref
para.sig_ulP    = 0;      % std. dev. labor supply
para.sig_uzP    = 0;      % std. dev. productivity
para.sig_ugP    = 0;      % std. dev. gov spend
para.sig_uiP    = 0;      % std. dev. monetary
para.sig_uphiP  = 0.01;   % std. dev. transaction costs

% Steady state values
% free steady state values
para.gyS    = 0.3;          % Government spending as fraction of output

% Implied steady state values
para.wS     = (para.thetaP - 1) / para.thetaP;                              % wage rate
para.cS     = ((1-para.gyS) ^ para.vphiP * (para.thetaP - 1)...
    / para.thetaP) ^ (1/(para.vphiP + para.sigmaP));                        % aggregate consumption
para.yS     = para.cS ^ (-para.sigmaP / para.vphiP) * ((para.thetaP - 1)...
    / para.thetaP) ^ (1 / para.vphiP);                                      % aggregate output
para.gS     = para.yS * para.gyS;                                           % aggregate public spending
para.tS     = -para.gS;                                                     % transfers
para.dS    = 1 / para.thetaP * para.yS;                                     % dividends

save para para
% keyboard
% Running the model calibration 1
dynare MIR_version2

load PlotStruct
PlotStruct.Model_1_irfs = oo_.irfs;
save PlotStruct PlotStruct


%% Parameter setting second calibration
load para
% para.omegaP     =     0.5;
% para.rho_uphiP = 0.5;
save para para

dynare MIR_version2

load PlotStruct
PlotStruct.Model_2_irfs = oo_.irfs;
save PlotStruct PlotStruct

%% Parameter setting third calibration
load para
% para.omegaP     =     0.95;
% para.rho_uphiP = 0.95;
save para para

dynare MIR_version2

load PlotStruct
PlotStruct.Model_3_irfs = oo_.irfs;
save PlotStruct PlotStruct

%% Plotting IRFs
load PlotStruct
plot_struct_1   = PlotStruct.Model_1_irfs;
plot_struct_2   = PlotStruct.Model_2_irfs;
plot_struct_3   = PlotStruct.Model_3_irfs;
varnames        = PlotStruct.varnames;
shockname       = PlotStruct.shockname;
periods         = PlotStruct.periods;
NegShock        = PlotStruct.NegShock;
Normalize       = PlotStruct.Normalize;
normvar         = PlotStruct.normvar;
normsize        = PlotStruct.normsize;

subplot_index = 1;

while subplot_index < 10
    plot_var    = char(varnames(subplot_index,1));
    plot_var_1  = eval(['plot_struct_1.',plot_var,'_',shockname]);
    plot_var_1  = plot_var_1';

    plot_var_2  = eval(['plot_struct_2.',plot_var,'_',shockname]);
    plot_var_2  = plot_var_2';    

    plot_var_3  = eval(['plot_struct_3.',plot_var,'_',shockname]);
    plot_var_3  = plot_var_3';  
    
    plot_var    = char(varnames(subplot_index,2));
    
    if Normalize == 1
        norm_1 = eval(['plot_struct_1.',normvar,'_', shockname]);
        norm_1 = norm_1(1,1);
        
        norm_2 = eval(['plot_struct_2.',normvar,'_', shockname]);
        norm_2 = norm_2(1,1);
        
        norm_3 = eval(['plot_struct_3.',normvar,'_', shockname]);
        norm_3 = norm_3(1,1);        
        
        plot_var_1 = normsize * plot_var_1 / norm_1;
        plot_var_2 = normsize * plot_var_2 / norm_2;
        plot_var_3 = normsize * plot_var_3 / norm_3;
        
    end
    
    if NegShock == 1
        plot_var_1 = - plot_var_1;
        plot_var_2 = - plot_var_2;
        plot_var_3 = - plot_var_3;
    end
    
    % making sure that very small irfs are ignored
    if norm(plot_var_1) < 1e-10
        plot_var_1 = zeros(size(plot_var_1));
    end
    
    if norm(plot_var_2) < 1e-10
        plot_var_2 = zeros(size(plot_var_2));
    end    
    
    if norm(plot_var_3) < 1e-10
        plot_var_3 = zeros(size(plot_var_3));
    end        
    
    figure(1)
        subplot(3,3,subplot_index)
        ha = plot(0:periods, plot_var_1(1:periods+1,1), 0:periods, plot_var_2(1:periods+1,1) , 0:periods, plot_var_3(1:periods+1,1));        
            set(ha(1), 'Linewidth', 2, 'Color',[0 1 0], 'Line', '-')
            set(ha(2), 'Linewidth', 2, 'Color',[0 1 0], 'Line', '-') 
            set(ha(3), 'Linewidth', 2, 'Color',[0 1 0], 'Line', '-')
        
%             set(ha(1), 'Linewidth', 2, 'Color',[0 0 1], 'Line', '-', 'Marker', 'o', 'MarkerSize',8)
%             set(ha(2), 'Linewidth', 2, 'Color',[0 1 0], 'Line', '-') 
%             set(ha(3), 'Linewidth', 2, 'Color',[1 0 0], 'Line', '-', 'Marker', 'x', 'MarkerSize',8) 
        title(plot_var)
        if subplot_index == 9
%             legend('\omega = 0.05','\omega = 0.50', '\omega = 0.95')
%             legend('\rho_{\phi} = 0.05','\rho_{\phi} = 0.50', '\rho_{\phi} = 0.95')            
%             legend('\omega = 1','\omega = 0.5', '\omega = 0.01')     
%             legend('wedge in rule','wedge NOT in rule')   
        end    
        
    subplot_index = subplot_index + 1;
end